class InternalServices(object):  # noqa
    DOCKERIZER = 'dockerizer'
    SIDECAR = 'sidecar'
    HELPER = 'helper'
    RUNNER = 'runner'

    VALUES = [
        DOCKERIZER,
        SIDECAR,
        HELPER,
        RUNNER
    ]
